"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addVerification = void 0;
const errors_1 = require("@feathersjs/errors");
const feathers_hooks_common_1 = require("feathers-hooks-common");
const helpers_1 = require("../helpers");
const options_1 = require("../options");
/**
 *
 * @param [path='authManagement'] the servicePath for your authManagement service
 * @returns
 */
function addVerification(path) {
    path = path || options_1.defaultPath; // default: 'authManagement'
    return (context) => __awaiter(this, void 0, void 0, function* () {
        (0, feathers_hooks_common_1.checkContext)(context, 'before', ['create', 'patch', 'update']);
        try {
            const { options } = context.app.service(path);
            const dataArray = (Array.isArray(context.data))
                ? context.data
                : [context.data];
            if ((['patch', 'update'].includes(context.method)) &&
                !!context.params.user &&
                dataArray.some(data => {
                    return !options.identifyUserProps.some((0, helpers_1.ensureFieldHasChanged)(data, context.params.user));
                })) {
                return context;
            }
            yield Promise.all(dataArray.map((data) => __awaiter(this, void 0, void 0, function* () {
                const [longToken, shortToken] = yield Promise.all([
                    (0, helpers_1.getLongToken)(options.longTokenLen),
                    (0, helpers_1.getShortToken)(options.shortTokenLen, options.shortTokenDigits)
                ]);
                data.isVerified = false;
                data.verifyExpires = Date.now() + options.delay;
                data.verifyToken = longToken;
                data.verifyShortToken = shortToken;
                data.verifyChanges = {};
            })));
            return context;
        }
        catch (err) {
            throw new errors_1.GeneralError(err);
        }
    });
}
exports.addVerification = addVerification;
