"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("@feathersjs/errors");
const debug_1 = __importDefault(require("debug"));
const helpers_1 = require("../helpers");
const debug = (0, debug_1.default)('authLocalMgnt:passwordChange');
function passwordChange(options, identifyUser, oldPassword, password, notifierOptions = {}, params) {
    return __awaiter(this, void 0, void 0, function* () {
        debug('passwordChange', oldPassword, password);
        if (params && "query" in params) {
            params = Object.assign({}, params);
            delete params.query;
        }
        const { app, identifyUserProps, passwordField, sanitizeUserForClient, service, notifier } = options;
        const usersService = app.service(service);
        const usersServiceId = usersService.id;
        (0, helpers_1.ensureValuesAreStrings)(oldPassword, password);
        (0, helpers_1.ensureObjPropsValid)(identifyUser, identifyUserProps);
        const users = yield usersService.find(Object.assign(Object.assign({}, params), { query: Object.assign(Object.assign({}, identifyUser), { $limit: 2 }), paginate: false }));
        const user = (0, helpers_1.getUserData)(users);
        try {
            yield (0, helpers_1.comparePasswords)(oldPassword, user.password);
        }
        catch (err) {
            throw new errors_1.BadRequest('Current password is incorrect.', {
                errors: { oldPassword: 'Current password is incorrect.' }
            });
        }
        const patchedUser = yield usersService.patch(user[usersServiceId], {
            password: yield (0, helpers_1.hashPassword)(app, password, passwordField)
        }, Object.assign({}, params));
        const userResult = yield (0, helpers_1.notify)(notifier, 'passwordChange', patchedUser, notifierOptions);
        return sanitizeUserForClient(userResult);
    });
}
exports.default = passwordChange;
